#[repr(u8)]pub enum MiscCtrlRegDisableViolationAbort {
_RESERVED_0 = 0,
NO_ABORT = 1,
ABORT = 2,
_RESERVED_3 = 3,
}Variants
_RESERVED_0 = 0
NO_ABORT = 1
The violation detected by the secure checker will not cause an abort, but a secure_violation_irq (interrupt request) will still be asserted and serviced by ISR.
ABORT = 2
The violation detected by the secure checker will cause an abort.
_RESERVED_3 = 3
Implementations